set more off
capture log close

global outputdata  D:/Users/khirvonen/Documents/Dropbox (IFPRI)/research/tax_and_social_protection/data/
global logfile D:/Users/khirvonen/Documents/Dropbox (IFPRI)/research/tax_and_social_protection/logfiles
global output D:\Users\khirvonen\Documents\Dropbox (IFPRI)\research\tax_and_social_protection

/*
global outputdata "/Users/giuliama/Dropbox/IDS/WIDER_Tax and SP/Data"
global logfile "/Users/giuliama/Dropbox/IDS/WIDER_Tax and SP/Log"
*/

log using "$logfile/eth_tax_sp_analysis_cons.log", replace

use "$outputdata/et_tax_sp_data_cons.dta", clear
*ind level file:
isid household_id2 individual_id2, sort

*drop HHs with with missing income
*we cannot compute the income shares for these households 
*and hence we cannot apply taxes on them:
assert  tax1_w==. if totincome_riga ==0
unique household_id2 if totincome_riga ==0
*225 individuals from 62 households
drop if totincome_riga ==0

 
*ANALYSIS:

* Table A2: Summary statistics of the income components:

mean c_agr_wge  c_nonagr_wge c_crop2 c_livestock  c_selfemp  c_transfer  c_other [pweight=pw2] 
 


*0) how many are affected by these policies:
foreach v of numlist 1/3 {
assert tax`v'_w!=.
assert tax`v'_se!=.
egen affected`v'=rowmax(tax`v'_w tax`v'_se)
replace affected`v'=1 if affected`v'>0
}
label var affected1 "paying taxes under current tax system"
label var affected2 "paying taxes after 2016 reform"
label var affected3 "paying taxes after drastic reform"

assert psnp_inc!=.
gen psnp=psnp_inc>0
label var psnp "PSNP beneficiary"

gen urban=rural!=1 
table urban [pweight=pw2], c(mean affected1 mean affected2   mean psnp) row format(%9.3f)
 
 

*1) calibrate poverty line:
 	pctile pct =  totcons_0_pc [pweight=pw2], nq(10) genp(percent)
	list percent pct  in 1/9, noobs separator(0)
	gen pline_i=3232.02
	drop pct percent
	label var pline "calibrated poverty line for consumption" 
	 
 
	/*calculate the total PSNP flows:
	gen temp=psnp_inc/hhsize
	collapse (sum)   temp [pweight=pw2]
	*/	
*2) now allocate PSNP funds equally to all poor ppl:
	preserve
	duplicates drop household_id2, force	 
 	total psnp_inc
	restore

	assert totcons_noPSNP_pc!=.
	gen cpoor_np=totcons_noPSNP_pc<3232.02
	tab cpoor_np
 
	*first number is 'total psnp_inc' 
	di 849364/6980
 
	gen totcons_pt=totcons_noPSNP_pc if cpoor_np==0
	replace totcons_p=totcons_noPSNP_pc+121.69 if cpoor_np==1
	assert totcons_pt!=.
	ren totcons_pt totcons_noPSNP_pc_pt
 
 sum  totcons_0  totcons_noPSNP_pc_pt
 
 
*3) Compute gini	(all incomes)



*Table 4: The estimated impacts under each scenario with respect to the base scenario using consumption data
 
*** GINI COEFFICIENTS (FIRST ROW): 
 
    fastgini   totcons_0_pc [pweight=pw2] //pre-tax  
    fastgini    totcons_1_pc [pweight=pw2] //current tax scheme
   	fastgini    totcons_2_pc [pweight=pw2] //2016 tax scheme 
	fastgini    totcons_noPSNP_pc  [pweight=pw2] //NO PSNP
	fastgini    totcons_noPSNP_pc_pt  [pweight=pw2] //PSNP  perfect targeting
 
 
glcurve totcons_0_pc [aweight=pw2],gl(g1) p(p1) nograph lorenz
glcurve totcons_1_pc [aweight=pw2],gl(g2) p(p2) nograph lorenz
glcurve totcons_2_pc [aweight=pw2],gl(g3) p(p3) nograph lorenz
glcurve totcons_noPSNP_pc [aweight=pw2],gl(g4) p(p4) nograph lorenz
glcurve totcons_noPSNP_pc_pt [aweight=pw2],gl(g5) p(p5) nograph lorenz

*Figure 1: Lorenz curves under base, pre-2016 and post-2016 scenarios
	twoway (line g1 p1, sort lpattern(dash)) (line g2 p2, sort lpattern(longdash)) (line g3 p3, sort lpattern(longdash_shortdash)) ///
	(function y=x, range(0 1) lpattern(solid)), ytitle("cumulative income proportion") ///
	ytitle(, margin(medsmall)) xtitle(population proportion) xtitle(, margin(medium)) ///
	legend(order(1 "Base" 2 "pre-2016 tax" 3 "post-2016 tax" 4 "45-degree line")) scheme(s1mono)
	graph export "$output\lorenz_tax.tif", as(tif) width(600) replace

*Figure 2: Lorenz curves under base, pre-2016 and post-2016 scenarios
	twoway (line g1 p1, sort lpattern(dash)) (line g4 p4, sort lpattern(longdash)) (line g5 p5, sort lpattern(longdash_shortdash)) ///
	(function y=x, range(0 1) lpattern(solid)), ytitle("cumulative income proportion") ///
	ytitle(, margin(medsmall)) xtitle(population proportion) xtitle(, margin(medium)) ///
	legend(order(1 "Base" 2 "No PSNP" 3 "Re-targeted PSNP" 4 "45-degree line")) scheme(s1mono)
	graph export "$output\lorenz_PSNP.tif", as(tif) width(600) replace
	 
 
*4) Estimate the full suite of FGT poverty indices:
	
 
 global inc totcons_0_pc

 	egen i0pov0 = fgt($inc),  w(pw2) pl(3232.02) a(0) 
	egen i0pov1 = fgt($inc),  w(pw2) pl(3232.02) a(1) 
	egen i0pov2 = fgt($inc),  w(pw2) pl(3232.02) a(2) 
 
 
 global inc totcons_1_pc

 	egen i1pov0 = fgt($inc),  w(pw2) pl(3232.02) a(0) 
	egen i1pov1 = fgt($inc),  w(pw2) pl(3232.02) a(1) 
	egen i1pov2 = fgt($inc),  w(pw2) pl(3232.02) a(2) 
 
 
  
 global inc totcons_2_pc

 	egen i2pov0 = fgt($inc),  w(pw2) pl(3232.02) a(0) 
	egen i2pov1 = fgt($inc),  w(pw2) pl(3232.02) a(1) 
	egen i2pov2 = fgt($inc),  w(pw2) pl(3232.02) a(2) 
	
	 
 
 
  global inc totcons_noPSNP_pc

 	egen i4pov0 = fgt($inc),  w(pw2) pl(3232.02) a(0) 
	egen i4pov1 = fgt($inc),  w(pw2) pl(3232.02) a(1) 
	egen i4pov2 = fgt($inc),  w(pw2) pl(3232.02) a(2) 
 

  global inc totcons_noPSNP_pc_pt

 	egen i5pov0 = fgt($inc),  w(pw2) pl(3232.02) a(0) 
	egen i5pov1 = fgt($inc),  w(pw2) pl(3232.02) a(1) 
	egen i5pov2 = fgt($inc),  w(pw2) pl(3232.02) a(2) 
 
*Table 4: The estimated impacts under each scenario with respect to the base scenario using consumption data
 
*** POV0, POV1 & POV2): 
 
sum i?pov0  , separator(0)
sum i?pov1  , separator(0)
sum i?pov2  , separator(0)
 
 x
 
*COST OF ELIMINATING POVERTY (FOR FIGURE 1):

*poverty line: 3232.02 birr
*head count poverty rate: 0.30
*poverty gap: 0.087
*total population: 89,983,203
*The per capita cost of eliminating poverty: 0.087 *3232.02  birr = 281.18 birr
*How much would it cost to eliminate poverty: 89,983,203  * 281.18 birr =  25,301,477,020  birr 

 

* TAX REVENUE TO ELIMINATE POVERTY

* How much more revenue with an MTR of 70%? 
drop tax?_w

d totaltax1 totaltax2 totaltax3 

collapse (mean) totaltax1 totaltax2 totaltax3 (firstnm) pw2 rural, by(household_id2)

gen tax1_w = (totaltax1 /1000000)  
gen tax2_w = (totaltax2 /1000000)  
gen tax3_w = (totaltax3 /1000000)  


table rural [pweight=pw2], row c(sum tax1_w sum tax2_w sum tax3_w) 

*the end

log close

 



*DATA AND CODE FOR FIGURE 3 & FIGURE A2:

mtr		gain		gain_inc
0.4		630.68		532.13
0.5		1892.04		843.61
0.6		3153.4		1155.08
0.7		4414.76		1466.56
0.8		5676.12		1778.03
0.9		6937.48		2089.51
1		8198.84		2400.99


*copy-paste this into Stata and then run these:

*eliminate poverty (cons data): 25,301,477,020 
*halve poverty (cons data):  12,650,738,510 


*Figure 1: Top marginal rate needed to eliminate poverty or fund the PSNP
twoway (connected gain mtr, sort  ), ytitle("Revenue gain (in million birr)") ytitle(, margin(medsmall)) ///
yline(3900 12651  , lpattern(dash)) xtitle("Top marginal tax rate") xtitle(, margin(medium)) xlabel(0.4(0.1)1, format(%2.1f)) ///
ylabel(0(3000)15000)   scheme(s1manual) ///
 text(13651 0.40 "halve poverty", place(e) size(small))  ///
text(4800 0.40 "finance PSNP", place(e) size(small))  
graph export "$output\Figure_3_consumption.tif", replace width(600) 


* eliminate poverty (inc data): 24,589,709,884 
* halve poverty (inc data):  12,294,854,942

*Figure A1: Top marginal rates and revenue gains using income data
twoway (connected gain_inc mtr, sort  ), ytitle("Revenue gain (in million birr)") ytitle(, margin(medsmall)) ///
yline(3900 12295  , lpattern(dash)) xtitle("Top marginal tax rate") xtitle(, margin(medium)) xlabel(0.4(0.1)1, format(%2.1f)) ///
 ylabel(0(3000)15000)  scheme(s1manual) ///
text(13295 0.40 "halve poverty", place(e) size(small))  ///
text(4600 0.40 "finance PSNP", place(e) size(small))   
graph export "$output\Figure_A2_income.tif", replace width(600) 
