set more off
capture log close

global outputdata  D:/Users/khirvonen/Documents/Dropbox (IFPRI)/research/tax_and_social_protection/data/
global logfile D:/Users/khirvonen/Documents/Dropbox (IFPRI)/research/tax_and_social_protection/logfiles
global output D:\Users\khirvonen\Documents\Dropbox (IFPRI)\research\tax_and_social_protection
/*

global outputdata "/Users/giuliama/Dropbox/IDS/WIDER_Tax and SP/Data"
global logfile "/Users/giuliama/Dropbox/IDS/WIDER_Tax and SP/Log"
*/
 log using "$logfile/eth_tax_sp_analysis_inc.log", replace

use "$outputdata/et_tax_sp_data_inc.dta", clear

*ind level file:
 isid household_id2 individual_id2, sort
 
*ANALYSIS:

* Table A2: Summary statistics of the income components:

mean agr_wge  wage crop2 livestock selfemp  transfer  other [pweight=pw2] 
 
 

*0) how many are affected by these policies:
foreach v of numlist 1/3 {
assert tax`v'_w!=.
assert tax`v'_se!=.
egen affected`v'=rowmax(tax`v'_w tax`v'_se)
replace affected`v'=1 if affected`v'>0
}
label var affected1 "paying taxes under current tax system"
label var affected2 "paying taxes after 2016 reform"
label var affected3 "paying taxes after drastic reform"

assert psnp_inc!=.
gen psnp=psnp_inc>0
label var psnp "PSNP beneficiary"

gen urban=rural!=1 
table urban [pweight=pw2], c(mean affected1 mean affected2 mean affected3 mean psnp) row format(%9.3f)



*1) calibrate poverty line:
 	pctile pct =  totincome_0_pc [pweight=pw2], nq(10) genp(percent)
	list percent pct  in 1/9, noobs separator(0)
	gen pline_i=1924.415
	drop pct percent
	label var pline "calibrated poverty line for income" 
	 
 
	*calculate the total PSNP flows:
	 *collapse (sum)   psnp_inc [pweight=pw2]

*2) now allocate PSNP funds equally to all poor ppl:
	preserve
	duplicates drop household_id2, force	 
 	total psnp_inc
	restore		 
 	assert totincome_noPSNP_pc!=.
	gen ipoor_np=totincome_noPSNP_pc<1924.415
	tab ipoor_np
 
	*first number is 'total psnp_inc' 
	di 849364 /8414
	 
	gen incomepc_pt=totincome_noPSNP_pc if ipoor_np==0
	replace incomepc_pt=totincome_noPSNP_pc+100.95 if ipoor_np==1
	assert incomepc_pt!=.
	ren incomepc_p totincome_noPSNP_pc_pt
 
 sum *inc*pc totincome_noPSNP_pc_pt
 
 
*3) Compute gini	(all incomes)

   	fastgini   totincome_0_pc [pweight=pw2] //pre-tax  
   	fastgini   totincome_1_pc [pweight=pw2] //current tax scheme
   	fastgini   totincome_2_pc [pweight=pw2] //2016 tax scheme 
 	fastgini   totincome_noPSNP_pc  [pweight=pw2] //NO PSNP
	fastgini   totincome_noPSNP_pc_pt  [pweight=pw2] //PSNP  perfect targeting
 
 
*4) Estimate the full suite of FGT poverty indices:
	
 
 global inc totincome_0_pc

 	egen i0pov0 = fgt($inc),  w(pw2) pl(1924.415) a(0) 
	egen i0pov1 = fgt($inc),  w(pw2) pl(1924.415) a(1) 
	egen i0pov2 = fgt($inc),  w(pw2) pl(1924.415) a(2) 
 
 
 global inc totincome_1_pc

 	egen i1pov0 = fgt($inc),  w(pw2) pl(1924.415) a(0) 
	egen i1pov1 = fgt($inc),  w(pw2) pl(1924.415) a(1) 
	egen i1pov2 = fgt($inc),  w(pw2) pl(1924.415) a(2) 
 
 
  
 global inc totincome_2_pc

 	egen i2pov0 = fgt($inc),  w(pw2) pl(1924.415) a(0) 
	egen i2pov1 = fgt($inc),  w(pw2) pl(1924.415) a(1) 
	egen i2pov2 = fgt($inc),  w(pw2) pl(1924.415) a(2) 
	
/*	 
 global inc totincome_3_pc

 	egen i3pov0 = fgt($inc),  w(pw2) pl(1924.415) a(0) 
	egen i3pov1 = fgt($inc),  w(pw2) pl(1924.415) a(1) 
	egen i3pov2 = fgt($inc),  w(pw2) pl(1924.415) a(2) 
*/ 
  global inc totincome_noPSNP_pc

 	egen i4pov0 = fgt($inc),  w(pw2) pl(1924.415) a(0) 
	egen i4pov1 = fgt($inc),  w(pw2) pl(1924.415) a(1) 
	egen i4pov2 = fgt($inc),  w(pw2) pl(1924.415) a(2) 
 

  global inc totincome_noPSNP_pc_pt

 	egen i5pov0 = fgt($inc),  w(pw2) pl(1924.415) a(0) 
	egen i5pov1 = fgt($inc),  w(pw2) pl(1924.415) a(1) 
	egen i5pov2 = fgt($inc),  w(pw2) pl(1924.415) a(2) 
 
*report  
 
sum i?pov0  , separator(0)

sum i?pov1  , separator(0)

sum i?pov2  , separator(0)

 
*COST OF ELIMINATING POVERTY (using income):

*poverty line: 1924.42 birr
*head count poverty rate: 0.30
*poverty gap: 0.142
*total population: 89,983,203
*The per capita cost of eliminating poverty: 0.142*1924.42  birr = 273.27 birr
*How much would it cost to eliminate poverty: 89,983,203   * 273.27 birr =  24,589,709,884  birr

 


* TAX REVENUE TO ELIMINATE POVERTY

* How much more revenue with an MTR of 70%? 

egen totaltax1 = rowtotal (tax1_w tax1_se)
egen totaltax2 = rowtotal (tax2_w tax2_se)
egen totaltax3 = rowtotal (tax3_w tax3_se)

collapse (mean) totaltax1 totaltax2 totaltax3 (firstnm) pw2 rural, by(household_id2)

gen tax1_w = (totaltax1 /1000000) * pw2
gen tax2_w = (totaltax2 /1000000) * pw2
gen tax3_w = (totaltax3 /1000000) * pw2


table rural, row c(sum tax1_w sum tax2_w sum tax3_w) 

x
*the end

log close
 
