
set more off 
capture log close


global rigadata D:/Users/khirvonen/Documents/Data/Ethiopia_LSMS_ISA/Ethiopia13
global consdata D:/Users/khirvonen/Documents/Data/Ethiopia_LSMS_ISA/r2013_14/data/Household
global hhdata D:/Users/khirvonen/Documents/Data/Ethiopia_LSMS_ISA/r2013_14/data/Household
global dofiles D:/Users/khirvonen/Documents/Dropbox (IFPRI)/research/tax_and_social_protection/dofiles
global outputdata  D:/Users/khirvonen/Documents/Dropbox (IFPRI)/research/tax_and_social_protection/data/
global logfile D:/Users/khirvonen/Documents/Dropbox (IFPRI)/research/tax_and_social_protection/logfiles

/*
global rigadata "/Users/giuliama/Dropbox/IDS/WIDER_Tax and SP/Data/RIGA/Ethiopia13_Kalle" 
global consdata "/Users/giuliama/Dropbox/IDS/WIDER_Tax and SP/Data/LSMS_2013/STATA/Household"
global hhdata "/Users/giuliama/Dropbox/IDS/WIDER_Tax and SP/Data/LSMS_2013/STATA/Household"
global temp "/Users/giuliama/Dropbox/IDS/WIDER_Tax and SP/Data/Temp_data"
global dofiles "/Users/giuliama/Dropbox/IDS/WIDER_Tax and SP/Do"
global outputdata  "/Users/giuliama/Dropbox/IDS/WIDER_Tax and SP/Data"
global logfile "/Users/giuliama/Dropbox/IDS/WIDER_Tax and SP/Log"

*/
log using "$logfile/eth_tax_sp_data_cons.log", replace

*adjust this global to generate the numbers for Figure 1:

global rate6 0.4
 
 
*We'll use the following income constructions:
* RIGA INCOME DATA
* WAGE DATA - CONSTRUCTED BY THE AUTHORS

*******************************************************************************************************************************************
*1) START WITH RIGA:
*******************************************************************************************************************************************
	
	
	use "$rigadata/Ethiopia13_HH_INCOME.dta" , clear

	/*
	RIGA totincome is formed of:

	1) ag wage
	2) non-ag wage
	3) crop income 
	4) livestock income
	5) inc from self employment
	6) transfers
	7) other income
	*/

	*in other words from these variables:

	d agr_wge nonagr_wge crop2 livestock selfemp transfer other

	*let's double-check this:

	egen temp=rowtotal(agr_wge nonagr_wge crop2 livestock selfemp transfer other)

	assert totincome2==temp
	*Correct
	drop temp

	
	
	*out of these taxable incomes are:
	*income from self-employment and non-ag wage income
	desc selfemp  nonagr_wge
	tempfile riga
	save `riga'

*******************************************************************************************************************************************
*2) Do the 'taxation' on consumption: 
*******************************************************************************************************************************************	
	
*merge with consumption aggregate file & construct key vars:

	ren hh household_id2
	merge 1:1 household_id2 using  "$consdata/cons_agg_w2.dta" 
	assert _m!=1
	keep if _m==3
	drop _m	

	*use total HH cons:
	d total_cons_ann
	*calculate inc shares of different components:
	foreach v of varlist agr_wge nonagr_wge crop2 livestock selfemp transfer other {
	gen sh_`v'=`v'/ totincome2
	label var sh_`v' "`v' share of total income"
	gen c_`v'=sh_`v'*total_cons_ann
	label var c_`v' "'consumption due to `v''"
	}
	sum sh_* 
	sum total_cons_ann  
	egen temp=rowtotal(c_*)
	count if abs(temp-total_cons_ann)>1
	sum totincome2 if abs(temp-total_cons_ann)>1
	*these are all with missing income data.
	*all good
	
	drop temp
	

*******************************************************************************************************************************************
*3) RECOMPUTE WAGES AND APPLY TAX SCHEMES
*******************************************************************************************************************************************

 ren c_nonagr_wge wage
 

	********* SYSTEM 1: CURRENT TAX SYSTEM *********

	gen bracket1 = . 
	replace bracket1 = 1800 if [_n]==1
	replace bracket1 = 7800 if [_n]==2
	replace bracket1 = 16800 if [_n]==3
	replace bracket1 = 28200 if [_n]==4
	replace bracket1 = 42600 if [_n]==5
	replace bracket1 = 60000 if [_n]==6

	xtile cat_bracket1 = wage, cutpoints(bracket1)  
	drop bracket1

	** THRESHOLDS
	gen thresh1=1800
	gen thresh2=7800
	gen thresh3=16800
	gen thresh4=28200
	gen thresh5=42600
	gen thresh6=60000

	* Tax Rates
	gen rate1=0.10
	gen rate2=0.15 
	gen rate3=0.20
	gen rate4=0.25
	gen rate5=0.30
	gen rate6=0.35

	gen tax1 = .
	replace tax1 = 0 if cat_bracket1==1
	replace tax1 = ((wage - thresh1)* rate1) if cat_bracket1==2
	replace tax1 = (((thresh2 - thresh1) * rate1) + ((wage - thresh2)* rate2)) if cat_bracket1==3
	replace tax1 = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((wage - thresh3)* rate3)) if cat_bracket1==4
	replace tax1 = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((wage - thresh4)* rate4)) if cat_bracket1==5
	replace tax1 = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((thresh5 - thresh4) * rate4) + ((wage - thresh5)* rate5)) if cat_bracket1==6
	replace tax1 = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((thresh5 - thresh4) * rate4) + ((thresh6 - thresh5) * rate5) + ((wage - thresh6)* rate6)) if cat_bracket1==7

	drop thresh1 thresh2 thresh3 thresh4 thresh5 thresh6 rate1 rate2 rate3 rate4 rate5 rate6 cat_bracket1

	gen net_inc1 = wage - (tax1)


	********* SYSTEM 2: 2016 REFORM *********

	gen bracket2 = . 
	replace bracket2 = 7000 if [_n]==1
	replace bracket2 = 19300 if [_n]==2
	replace bracket2 = 37750 if [_n]==3
	replace bracket2 = 62350 if [_n]==4
	replace bracket2 = 93100 if [_n]==5
	replace bracket2 = 130000 if [_n]==6
	xtile cat_bracket2 = wage, cutpoints(bracket2) 
	drop bracket2

	** Thresholds
	gen thresh1=7000
	gen thresh2=19300
	gen thresh3=37750
	gen thresh4=62350
	gen thresh5=93100
	gen thresh6=130000

	* Tax Rate
	gen rate1=0.10
	gen rate2=0.15 
	gen rate3=0.20
	gen rate4=0.25
	gen rate5=0.30
	gen rate6=0.35

	gen tax2 = .
	replace tax2 = 0 if cat_bracket2==1
	replace tax2 = ((wage - thresh1)* rate1) if cat_bracket2==2
	replace tax2 = (((thresh2 - thresh1) * rate1) + ((wage - thresh2)* rate2)) if cat_bracket2==3
	replace tax2 = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((wage - thresh3)* rate3)) if cat_bracket2==4
	replace tax2 = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((wage - thresh4)* rate4)) if cat_bracket2==5
	replace tax2 = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((thresh5 - thresh4) * rate4) + ((wage - thresh5)* rate5)) if cat_bracket2==6
	replace tax2 = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((thresh5 - thresh4) * rate4) + ((thresh6 - thresh5) * rate5) + ((wage - thresh6)* rate6)) if cat_bracket2==7

	drop thresh1 thresh2 thresh3 thresh4 thresh5 thresh6 rate1 rate2 rate3 rate4 rate5 rate6 cat_bracket2

	gen net_inc2 = wage - (tax2)


	********* SYSTEM 3: ELIMINATE POVERTY (70% MTR) *********
	
	
	gen bracket2 = . 
	replace bracket2 = 7000 if [_n]==1
	replace bracket2 = 19300 if [_n]==2
	replace bracket2 = 37750 if [_n]==3
	replace bracket2 = 62350 if [_n]==4
	replace bracket2 = 93100 if [_n]==5
	replace bracket2 = 130000 if [_n]==6
	xtile cat_bracket2 = wage, cutpoints(bracket2) 
	drop bracket2

	** Thresholds
	gen thresh1=7000
	gen thresh2=19300
	gen thresh3=37750
	gen thresh4=62350
	gen thresh5=93100
	gen thresh6=130000

	* Tax Rate
	gen rate1=0.10
	gen rate2=0.15 
	gen rate3=0.20
	gen rate4=0.25
	gen rate5=0.30
	gen rate6=$rate6
 
	gen tax3 = .
	replace tax3 = 0 if cat_bracket2==1
	replace tax3 = ((wage - thresh1)* rate1) if cat_bracket2==2
	replace tax3 = (((thresh2 - thresh1) * rate1) + ((wage - thresh2)* rate2)) if cat_bracket2==3
	replace tax3 = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((wage - thresh3)* rate3)) if cat_bracket2==4
	replace tax3 = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((wage - thresh4)* rate4)) if cat_bracket2==5
	replace tax3 = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((thresh5 - thresh4) * rate4) + ((wage - thresh5)* rate5)) if cat_bracket2==6
	replace tax3 = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((thresh5 - thresh4) * rate4) + ((thresh6 - thresh5) * rate5) + ((wage - thresh6)* rate6)) if cat_bracket2==7

	drop thresh1 thresh2 thresh3 thresh4 thresh5 thresh6 rate1 rate2 rate3 rate4 rate5 rate6 cat_bracket2

	gen net_inc3 = wage - (tax3)


	ren net_inc1 wage1
 	ren net_inc2 wage2
 	ren net_inc3 wage3
 	 
	*tidy up & save
 	isid household_id2  , sort

	d rural pw2 saq01
 
 	label var wage1 "cons due to non-agr wage after tax (current system)"
	label var wage2 "cons due to non-agr wage after tax (2016 reform)"
	label var wage3 "cons due to non-agr wage after tax (70% MTR)"
	ren wage1 c_nonagr_wge1
	ren wage2 c_nonagr_wge2
	ren wage3 c_nonagr_wge3
	ren  wage c_nonagr_wge


	compress
tempfile wages
save `wages'
 

*******************************************************************************************************************************************
*3) MERGE
*******************************************************************************************************************************************
	use `riga'

	*let's use the values we computed earlier instead (these are both before taxes):

	*merge in the data GM prepared earlier
	ren hhid household_id2  
	merge 1:1  household_id2   using `wages'
	*analyze the merge!
	assert _m!=1
	keep if _m==3
	drop _m
 
 
*******************************************************************************************************************************************
*4) APPLY TAAX SCENARIOS FOR INCOME FROM SELF EMPLOYMENT
*******************************************************************************************************************************************
ren  selfemp selfemp_riga

ren c_selfemp selfemp

	********* SYSTEM 1: CURRENT TAX SYSTEM *********

	gen bracket1 = . 
	replace bracket1 = 1800 if [_n]==1
	replace bracket1 = 7800 if [_n]==2
	replace bracket1 = 16800 if [_n]==3
	replace bracket1 = 28200 if [_n]==4
	replace bracket1 = 42600 if [_n]==5
	replace bracket1 = 60000 if [_n]==6

	xtile cat_bracket1 = selfemp, cutpoints(bracket1)  
	drop bracket1

	** THRESHOLDS
	gen thresh1=1800
	gen thresh2=7800
	gen thresh3=16800
	gen thresh4=28200
	gen thresh5=42600
	gen thresh6=60000

	* Tax Rates
	gen rate1=0.10
	gen rate2=0.15 
	gen rate3=0.20
	gen rate4=0.25
	gen rate5=0.30
	gen rate6=0.35

	gen tax1_se = .
	replace tax1_se = 0 if cat_bracket1==1
	replace tax1_se = ((selfemp - thresh1)* rate1) if cat_bracket1==2
	replace tax1_se = (((thresh2 - thresh1) * rate1) + ((selfemp - thresh2)* rate2)) if cat_bracket1==3
	replace tax1_se = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((selfemp - thresh3)* rate3)) if cat_bracket1==4
	replace tax1_se = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((selfemp - thresh4)* rate4)) if cat_bracket1==5
	replace tax1_se = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((thresh5 - thresh4) * rate4) + ((selfemp - thresh5)* rate5)) if cat_bracket1==6
	replace tax1_se = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((thresh5 - thresh4) * rate4) + ((thresh6 - thresh5) * rate5) + ((selfemp - thresh6)* rate6)) if cat_bracket1==7

	drop thresh1 thresh2 thresh3 thresh4 thresh5 thresh6 rate1 rate2 rate3 rate4 rate5 rate6 cat_bracket1

	gen net_seinc1 = selfemp - (tax1_se)

	********* SYSTEM 2: 2016 REFORM *********

	gen bracket2 = . 
	replace bracket2 = 7000 if [_n]==1
	replace bracket2 = 19300 if [_n]==2
	replace bracket2 = 37750 if [_n]==3
	replace bracket2 = 62350 if [_n]==4
	replace bracket2 = 93100 if [_n]==5
	replace bracket2 = 130000 if [_n]==6
	xtile cat_bracket2 = selfemp, cutpoints(bracket2) 
	drop bracket2

	** Thresholds
	gen thresh1=7000
	gen thresh2=19300
	gen thresh3=37750
	gen thresh4=62350
	gen thresh5=93100
	gen thresh6=130000

	* Tax Rate
	gen rate1=0.10
	gen rate2=0.15 
	gen rate3=0.20
	gen rate4=0.25
	gen rate5=0.30
	gen rate6=0.35

	gen tax2_se = .
	replace tax2_se = 0 if cat_bracket2==1
	replace tax2_se = ((selfemp - thresh1)* rate1) if cat_bracket2==2
	replace tax2_se = (((thresh2 - thresh1) * rate1) + ((selfemp - thresh2)* rate2)) if cat_bracket2==3
	replace tax2_se = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((selfemp - thresh3)* rate3)) if cat_bracket2==4
	replace tax2_se = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((selfemp - thresh4)* rate4)) if cat_bracket2==5
	replace tax2_se = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((thresh5 - thresh4) * rate4) + ((selfemp - thresh5)* rate5)) if cat_bracket2==6
	replace tax2_se = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((thresh5 - thresh4) * rate4) + ((thresh6 - thresh5) * rate5) + ((selfemp - thresh6)* rate6)) if cat_bracket2==7

	drop thresh1 thresh2 thresh3 thresh4 thresh5 thresh6 rate1 rate2 rate3 rate4 rate5 rate6 cat_bracket2

	gen net_seinc2 = selfemp - (tax2_se)


	********* SYSTEM 3: ELIMINATE POVERTY (70% MTR) *********

	gen bracket2 = . 
	replace bracket2 = 7000 if [_n]==1
	replace bracket2 = 19300 if [_n]==2
	replace bracket2 = 37750 if [_n]==3
	replace bracket2 = 62350 if [_n]==4
	replace bracket2 = 93100 if [_n]==5
	replace bracket2 = 130000 if [_n]==6
	xtile cat_bracket2 = selfemp, cutpoints(bracket2) 
	drop bracket2

	** Thresholds
	gen thresh1=7000
	gen thresh2=19300
	gen thresh3=37750
	gen thresh4=62350
	gen thresh5=93100
	gen thresh6=130000

	* Tax Rate
	gen rate1=0.10
	gen rate2=0.15 
	gen rate3=0.20
	gen rate4=0.25
	gen rate5=0.30
	gen rate6=$rate6

	gen tax3_se = .
	replace tax3_se = 0 if cat_bracket2==1
	replace tax3_se = ((selfemp - thresh1)* rate1) if cat_bracket2==2
	replace tax3_se = (((thresh2 - thresh1) * rate1) + ((selfemp - thresh2)* rate2)) if cat_bracket2==3
	replace tax3_se = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((selfemp - thresh3)* rate3)) if cat_bracket2==4
	replace tax3_se = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((selfemp - thresh4)* rate4)) if cat_bracket2==5
	replace tax3_se = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((thresh5 - thresh4) * rate4) + ((selfemp - thresh5)* rate5)) if cat_bracket2==6
	replace tax3_se = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((thresh5 - thresh4) * rate4) + ((thresh6 - thresh5) * rate5) + ((selfemp - thresh6)* rate6)) if cat_bracket2==7

	drop thresh1 thresh2 thresh3 thresh4 thresh5 thresh6 rate1 rate2 rate3 rate4 rate5 rate6 cat_bracket2
	
	gen net_seinc3 = selfemp - (tax3_se)

	label var net_seinc1 "net cons due  self-employment inc (current tax system)"
	label var net_seinc2 "net cons due  self-employment inc (2016 tax reform)"
	label var net_seinc3 "net cons due  self-employment inc (70% MTR)"
	ren net_seinc1 c_selfemp1
	ren net_seinc2 c_selfemp2
	ren net_seinc3 c_selfemp3


	ren selfemp c_selfemp

  	ren selfemp_riga selfemp

  
*******************************************************************************************************************************************
*5) MERGE IN OTHER HOUSEHOLD LEVEL VARIABLES
*******************************************************************************************************************************************
 
* merge with the riga hh characteristics data (to get the hh size variables):
	ren household_id2 hh
	merge 1:1 hh using    "$rigadata/Ethiopia13_HHCHAR.dta" 
	assert _m!=1
	keep if _m==3
	drop _m
	
	

 
	gen   totincome_riga_pc=totincome2/adulteq
	ren totincome2  totincome_riga
	label var totincome_riga_pc "total income (RIGA) per adult equivalent"
	label var totincome_riga "total income (RIGA)"
	
	label var tax1 "tax on wages (current tax system)"
	label var tax2 "tax on wages (2016 tax reform)"
	label var tax3 "tax on wages (drastic tax reform)"
	ren tax1 tax1_w
	ren tax2 tax2_w
	ren tax3 tax3_w

	label var tax1_se "tax on SE income (current tax system)"
	label var tax2_se "tax on SE income (2016 tax reform)"
	label var tax3_se "tax on SE income (drastic tax reform)"

	gen total_cons_pc=total_cons_ann/adulteq
	label var total_cons_pc "total HH consumption per adult equivalent"
	
	 
	*keep household_id2 agr_wge wage wage? crop2 livestock selfemp selfemp? transfer other  adulteq  totincome_riga* pw tax* total_cons_* agr_wge nonagr_wge crop2 livestock selfemp transfer other

	*construct all cons variables:
	 
 	*PRE-TAX CONS
	ren total_cons_ann totcons_0
	assert totcons_0>0
	gen  totcons_0_pc= totcons_0/adulteq
	label var totcons_0_pc "total consumption per adult equivalent (pre-tax)"
	 
 
 
	*NET-CONS - CURRENT TAX SCHEME
	egen totcons_1=rowtotal(c_agr_wge c_nonagr_wge1  c_crop2  c_livestock c_selfemp1  c_transfer c_other), missing
	assert totcons_1>0
	label var totcons_1 "net total cons (current tax scheme)"
	gen  totcons_1_pc= totcons_1/adulteq
	label var totcons_1_pc "net total cons per adult equivalent (current tax scheme)"
	 
	 
	*NET-INCOME - POST JULY SCHEME
	egen totcons_2=rowtotal(c_agr_wge c_nonagr_wge2  c_crop2  c_livestock c_selfemp2  c_transfer c_other), missing
	assert totcons_2>0
	label var totcons_2 "net total cons (post july tax scheme)"
	gen  totcons_2_pc= totcons_2/adulteq
	label var totcons_2_pc "net total cons per adult equivalent (post july scheme)"
 

	count


	ren hh hhid

*******************************************************************************************************************************************
*6) PREPARE DATA FOR THE SOCIAL PROTECTION ANALYSIS
*******************************************************************************************************************************************	
	
preserve
	*a) gather information about public works incomes:
	use "$hhdata/sect4_hh_w2.dta" , clear
	d hh_s4q01
	keep if hh_s4q01=="X"
	d hh_s4q3?

	gen pw_inc=hh_s4q33 
	 

	ren household_id2 hhid
	collapse (sum ) pw_inc, by(hhid )
	count if pw_inc>0
	tempfile pw_inc
	save `pw_inc'
 
	*b) gather information about direct support incomes:
	use "$hhdata/sect13_hh_w2.dta" , clear
	tab hh_s13q01
	keep if  hh_s13q01==1
	tab hh_s13q02_b
	keep if hh_s13q00=="A" //PSNP related assistance  //updated: 10 August 2017
  	egen ds_inc=rowtotal(hh_s13q03 hh_s13q04 hh_s13q05)
	ren household_id2 hhid
	collapse (sum ) ds_inc, by(hhid )

	*merge with PW income data:
	merge 1:1 hhid using `pw_inc'
	assert _m!=1
	drop _m
	 
	replace ds_inc=0 if ds_inc==.
	assert pw_inc!=.
	assert ds_inc!=.
	egen psnp_inc=rowtotal(pw_inc ds_inc)
	count if psnp_inc>0
	tempfile sp
	save `sp'
	
restore
	 
*******************************************************************************************************************************************
*7) MERGE WITH CONS DATA
*******************************************************************************************************************************************		
    
	merge 1:1 hhid using `sp'
	keep if _m==3
	drop _m
 
	
	assert psnp_inc!=.
	count if psnp_inc>0
 
	 
 	gen totcons_noPSNP_pc=(totcons_0-psnp_inc)/adulteq
 	label var totcons_noPSNP_pc "HH total cons per adult equivalent - PSNP income"	
    sum totcons_noPSNP
	replace totcons_noPSNP=1  if totcons_noPSNP<=0
 

	*calculate the total PSNP flows:
	*collapse (sum)   psnp_inc [pweight=pw2]
 
  
	total psnp_inc
  
	ren hhid household_id2 
	

	count if psnp_inc>0 
	total psnp_inc 
	*estimate total PSNP flows from the data:
	*collapse (total) total psnp_inc [pweight=pw2]

	
*compute total taxes paid:	
	egen totaltax1 = rowtotal (tax1_w tax1_se)
	egen totaltax2 = rowtotal (tax2_w tax2_se)
	egen totaltax3 = rowtotal (tax3_w tax3_se)
	
*******************************************************************************************************************************************
*9) TRANSFORM TO INDIVIDUAL LEVEL
*******************************************************************************************************************************************	
 
	merge 1:m household_id2 using  "$hhdata/sect1_hh_w2.dta", keepusing(individual_id2  saq01  pw2 rural)
	isid household_id2 individual_id2, sort
 	assert _m!=1
	keep if _m==3
	drop _m
	count if psnp_inc>0 
 	 
*******************************************************************************************************************************************
*10) TIDY UP AND SAVE
*******************************************************************************************************************************************	

	*keep household_id2- saq01 tax*
	order household_id2   saq01 rural pw2
	drop    ds_inc pw_inc  
	qui compress
	
label data "final data used for the tax & social protection paper (2 Sept 2016)"
save "$outputdata/et_tax_sp_data_cons.dta", replace
	
 
	
*the end

log close
 
 
