
set more off 
capture log close

global rigadata D:/Users/khirvonen/Documents/Data/Ethiopia_LSMS_ISA/Ethiopia13
global consdata D:/Users/khirvonen/Documents/Data/Ethiopia_LSMS_ISA/r2013_14/data/Household
global hhdata D:/Users/khirvonen/Documents/Data/Ethiopia_LSMS_ISA/r2013_14/data/Household
global dofiles D:/Users/khirvonen/Documents/Dropbox (IFPRI)/research/tax_and_social_protection/dofiles
global outputdata  D:/Users/khirvonen/Documents/Dropbox (IFPRI)/research/tax_and_social_protection/data/
global logfile D:/Users/khirvonen/Documents/Dropbox (IFPRI)/research/tax_and_social_protection/logfiles
/*
global rigadata "/Users/giuliama/Dropbox/IDS/WIDER_Tax and SP/Data/RIGA/Ethiopia13_Kalle" 
global consdata "/Users/giuliama/Dropbox/IDS/WIDER_Tax and SP/Data/LSMS_2013/STATA/Household"
global hhdata "/Users/giuliama/Dropbox/IDS/WIDER_Tax and SP/Data/LSMS_2013/STATA/Household"
global temp "/Users/giuliama/Dropbox/IDS/WIDER_Tax and SP/Data/Temp_data"
global dofiles "/Users/giuliama/Dropbox/IDS/WIDER_Tax and SP/Do"
global outputdata  "/Users/giuliama/Dropbox/IDS/WIDER_Tax and SP/Data"
global logfile "/Users/giuliama/Dropbox/IDS/WIDER_Tax and SP/Log"
*/
log using "$logfile/eth_tax_sp_data_inc.log", replace

 

global rate6 1.0

*******************************************************************************************************************************************
*1) START WITH RIGA:
*******************************************************************************************************************************************
	
	
	use "$rigadata/Ethiopia13_HH_INCOME.dta" , clear

	/*
	RIGA totincome is formed of:

	1) ag wage
	2) non-ag wage
	3) crop income 
	4) livestock income
	5) inc from self employment
	6) transfers
	7) other income
	*/

	*in other words from these variables:

	d agr_wge nonagr_wge crop2 livestock selfemp transfer other

	*let's double-check this:

	egen temp=rowtotal(agr_wge nonagr_wge crop2 livestock selfemp transfer other)

	assert totincome2==temp
	*Correct
	drop temp

	*out of these taxable incomes are:
	*income from self-employment and non-ag wage income
	desc selfemp  nonagr_wge
	tempfile riga
	save `riga'


*******************************************************************************************************************************************
*2) RECOMPUTE WAGES AND APPLY TAX SCHEMES
*******************************************************************************************************************************************

	*** GENERATE YEARLY WAGES ***
 
	use "$hhdata/sect4_hh_w2.dta", clear
	 
	/* PRIMARY JOB: convert all wages in yearly: 
		Note: To calculate yearly wage from daily values, I am assuming 8 hours per day 
		because this is the average when considering between 5 and 6 days worked per week. 
		For other calculations we simply use the hours per week and weeks per month 
		as reported in the survey. */
		
	d hh_s4q1?

	d hh_s4q13 hh_s4q14 hh_s4q15 hh_s4q16 hh_s4q17  

	*assume 6 day working week
	gen days=hh_s4q15/7
	replace days=round(days, 1)
	replace days=7 if days>7 & days<.

	 

	label list HH_S4Q17
	tab hh_s4q17
	 

	gen wage_1=.
	replace wage_1=hh_s4q16*hh_s4q15*hh_s4q14*hh_s4q13 if hh_s4q17==1
	replace wage_1=hh_s4q16*days*hh_s4q14*hh_s4q13  if hh_s4q17==2
	replace wage_1=hh_s4q16*hh_s4q13 *hh_s4q14  if hh_s4q17==3
	replace wage_1=(hh_s4q16/2)*hh_s4q13 *hh_s4q14  if hh_s4q17==4
	replace wage_1=hh_s4q16* hh_s4q13   if hh_s4q17==5
	replace wage_1=(hh_s4q16/4)*hh_s4q13  if hh_s4q17==6
	replace wage_1=(hh_s4q16/6)*hh_s4q13  if hh_s4q17==7
	replace wage_1=hh_s4q16  if hh_s4q17==8

 
	*check for outliers:

	sum wage_1, det
	sort wage_1
	
	list   hh_s4q10_b hh_s4q16 hh_s4q17 wage_1 if wage_1>151200 & wage_1!=., noobs separator(0)
	 
	*those with daily or hourly salaries are unlikely to earn this much:
    gen outlier=1 if wage_1>151200 & wage_1!=. & hh_s4q17!=5
	sum outlier
	gen tempwage=wage_1 if  wage_1!=0 
	egen med_wage_1=median(tempwage), by(saq01 hh_s4q10_b)
	replace wage_1=med_wage_1 if outlier==1

	d hh_s4q25-hh_s4q28
	 
  
    *ignore allowances / gratuities:
	d hh_s4q18 hh_s4q19
	count if hh_s4q18>0 & hh_s4q18<.
    
	
	
	
	* SECONDARY JOB: convert all wages in yearly:

	drop hh_s4q16 hh_s4q15 hh_s4q14 hh_s4q13 hh_s4q17 days

	*assume 6 day working week
	gen days=hh_s4q26/7
	replace days=round(days, 1)
	replace days=7 if days>7 & days<.

	ren hh_s4q27  hh_s4q16
	ren hh_s4q28  hh_s4q17
	ren hh_s4q26  hh_s4q15	
	ren hh_s4q24  hh_s4q13	
	ren hh_s4q25  hh_s4q14

	gen wage_2=.
	replace wage_2=hh_s4q16*hh_s4q15*hh_s4q14*hh_s4q13 if hh_s4q17==1
	replace wage_2=hh_s4q16*days*hh_s4q14*hh_s4q13  if hh_s4q17==2
	replace wage_2=hh_s4q16*hh_s4q13 *hh_s4q14  if hh_s4q17==3
	replace wage_2=(hh_s4q16/2)*hh_s4q13 *hh_s4q14  if hh_s4q17==4
	replace wage_2=hh_s4q16* hh_s4q13   if hh_s4q17==5
	replace wage_2=(hh_s4q16/4)*hh_s4q13  if hh_s4q17==6
	replace wage_2=(hh_s4q16/6)*hh_s4q13  if hh_s4q17==7
	replace wage_2=hh_s4q16  if hh_s4q17==8
	 
	gen agr_wage1=wage_1 if hh_s4q11_b==1
	gen n_wage1=wage_1 if inrange(hh_s4q11_b,2,18)

	gen agr_wage2=wage_2 if hh_s4q22_b ==1
	gen n_wage2=wage_2 if inrange(hh_s4q22_b ,2,18)

	* PSNP JOB: all wages are already yearly:
	*assume all agr related:
	gen agr_wage4 = hh_s4q33

	* CASUAL AND OTHER JOB: all wages are already yearly:
	gen wage_5 = hh_s4q36
	*assume all casual wages in rural areas are agr related
	gen agr_wage5=wage_5 if rural ==1
	gen n_wage5=wage_5 if rural !=1


	 
	* Total wages
	egen agr_wage=rowtotal(agr_wage1 agr_wage2 agr_wage4 agr_wage5)
	egen nagr_wage=rowtotal(n_wage1 n_wage2  		     n_wage5)
	 
	*use total non ag wage for tax analysis 
	gen wage=nagr_wage  

	 
	 
	***************************
	******* TAX SYSTEM ********
	*** GENERATE SCENARIOS ****
	***************************


	********* SYSTEM 1: CURRENT TAX SYSTEM *********

	gen bracket1 = . 
	replace bracket1 = 1800 if [_n]==1
	replace bracket1 = 7800 if [_n]==2
	replace bracket1 = 16800 if [_n]==3
	replace bracket1 = 28200 if [_n]==4
	replace bracket1 = 42600 if [_n]==5
	replace bracket1 = 60000 if [_n]==6

	xtile cat_bracket1 = wage, cutpoints(bracket1)  
	drop bracket1

	** THRESHOLDS
	gen thresh1=1800
	gen thresh2=7800
	gen thresh3=16800
	gen thresh4=28200
	gen thresh5=42600
	gen thresh6=60000

	* Tax Rates
	gen rate1=0.10
	gen rate2=0.15 
	gen rate3=0.20
	gen rate4=0.25
	gen rate5=0.30
	gen rate6=$rate6

	gen tax1 = .
	replace tax1 = 0 if cat_bracket1==1
	replace tax1 = ((wage - thresh1)* rate1) if cat_bracket1==2
	replace tax1 = (((thresh2 - thresh1) * rate1) + ((wage - thresh2)* rate2)) if cat_bracket1==3
	replace tax1 = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((wage - thresh3)* rate3)) if cat_bracket1==4
	replace tax1 = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((wage - thresh4)* rate4)) if cat_bracket1==5
	replace tax1 = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((thresh5 - thresh4) * rate4) + ((wage - thresh5)* rate5)) if cat_bracket1==6
	replace tax1 = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((thresh5 - thresh4) * rate4) + ((thresh6 - thresh5) * rate5) + ((wage - thresh6)* rate6)) if cat_bracket1==7

	drop thresh1 thresh2 thresh3 thresh4 thresh5 thresh6 rate1 rate2 rate3 rate4 rate5 rate6 cat_bracket1

	gen net_inc1 = wage - (tax1)


	********* SYSTEM 2: 2016 REFORM *********

	gen bracket2 = . 
	replace bracket2 = 7000 if [_n]==1
	replace bracket2 = 19300 if [_n]==2
	replace bracket2 = 37750 if [_n]==3
	replace bracket2 = 62350 if [_n]==4
	replace bracket2 = 93100 if [_n]==5
	replace bracket2 = 130000 if [_n]==6
	xtile cat_bracket2 = wage, cutpoints(bracket2) 
	drop bracket2

	** Thresholds
	gen thresh1=7000
	gen thresh2=19300
	gen thresh3=37750
	gen thresh4=62350
	gen thresh5=93100
	gen thresh6=130000

	* Tax Rate
	gen rate1=0.10
	gen rate2=0.15 
	gen rate3=0.20
	gen rate4=0.25
	gen rate5=0.30
	gen rate6=0.35

	gen tax2 = .
	replace tax2 = 0 if cat_bracket2==1
	replace tax2 = ((wage - thresh1)* rate1) if cat_bracket2==2
	replace tax2 = (((thresh2 - thresh1) * rate1) + ((wage - thresh2)* rate2)) if cat_bracket2==3
	replace tax2 = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((wage - thresh3)* rate3)) if cat_bracket2==4
	replace tax2 = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((wage - thresh4)* rate4)) if cat_bracket2==5
	replace tax2 = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((thresh5 - thresh4) * rate4) + ((wage - thresh5)* rate5)) if cat_bracket2==6
	replace tax2 = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((thresh5 - thresh4) * rate4) + ((thresh6 - thresh5) * rate5) + ((wage - thresh6)* rate6)) if cat_bracket2==7

	drop thresh1 thresh2 thresh3 thresh4 thresh5 thresh6 rate1 rate2 rate3 rate4 rate5 rate6 cat_bracket2

	gen net_inc2 = wage - (tax2)


	********* SYSTEM 3: ELIMINATE POVERTY (70% MTR) *********

	gen bracket2 = . 
	replace bracket2 = 7000 if [_n]==1
	replace bracket2 = 19300 if [_n]==2
	replace bracket2 = 37750 if [_n]==3
	replace bracket2 = 62350 if [_n]==4
	replace bracket2 = 93100 if [_n]==5
	replace bracket2 = 130000 if [_n]==6
	xtile cat_bracket2 = wage, cutpoints(bracket2) 
	drop bracket2

	** Thresholds
	gen thresh1=7000
	gen thresh2=19300
	gen thresh3=37750
	gen thresh4=62350
	gen thresh5=93100
	gen thresh6=130000

	* Tax Rate
	gen rate1=0.10
	gen rate2=0.15 
	gen rate3=0.20
	gen rate4=0.25
	gen rate5=0.30
	gen rate6=$rate6

	gen tax3 = .
	replace tax3 = 0 if cat_bracket2==1
	replace tax3 = ((wage - thresh1)* rate1) if cat_bracket2==2
	replace tax3 = (((thresh2 - thresh1) * rate1) + ((wage - thresh2)* rate2)) if cat_bracket2==3
	replace tax3 = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((wage - thresh3)* rate3)) if cat_bracket2==4
	replace tax3 = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((wage - thresh4)* rate4)) if cat_bracket2==5
	replace tax3 = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((thresh5 - thresh4) * rate4) + ((wage - thresh5)* rate5)) if cat_bracket2==6
	replace tax3 = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((thresh5 - thresh4) * rate4) + ((thresh6 - thresh5) * rate5) + ((wage - thresh6)* rate6)) if cat_bracket2==7

	drop thresh1 thresh2 thresh3 thresh4 thresh5 thresh6 rate1 rate2 rate3 rate4 rate5 rate6 cat_bracket2

	gen net_inc3 = wage - (tax3)
	
	
	ren net_inc1 wage1
	label var wage1 "wage after tax (current system)"
	ren net_inc2 wage2
	label var wage2 "wage after tax (2016 reform)"
	ren net_inc3 wage3
	label var wage3 "wage after tax (70% MTR)"
	 
	*tidy up & save
	keep household_id2 individual_id2 wage wage? rural pw2 saq01 tax1 tax2 tax3 agr_wage
	isid household_id2 individual_id2, sort

	d rural pw2 saq01
	*collapse to hh level:
	 
	collapse (sum) tax1 tax2 tax3 wage wage? agr_wage (min) rural   pw2 saq01, by(household_id2)
	label var agr_wage "agr wage (own calculation)" 
	label var wage "non-agr wage "
	label var wage1 "non-agr wage after tax (current system)"
	label var wage2 "non-agr wage after tax (2016 reform)"
	label var wage3 "non-agr wage after tax (drastic reform)"
	compress



tempfile wages
save `wages'


*******************************************************************************************************************************************
*3) MERGE
*******************************************************************************************************************************************
	use `riga'

	*let's use the values we computed earlier instead (these are both before taxes):

	*merge in the data GM prepared earlier
	ren hhid household_id2  
	merge 1:1  household_id2   using `wages'
	*analyze the merge!
	assert _m!=1
	keep if _m==3
	drop _m
	sum agr_wage agr_wge //pretty good --> let's use the RIGA computation!
	sum wage   nonagr_wg //OK
 
*******************************************************************************************************************************************
*4) APPLY TAAX SCENARIOS FOR INCOME FROM SELF EMPLOYMENT
*******************************************************************************************************************************************



	********* SYSTEM 1: CURRENT TAX SYSTEM *********

	gen bracket1 = . 
	replace bracket1 = 1800 if [_n]==1
	replace bracket1 = 7800 if [_n]==2
	replace bracket1 = 16800 if [_n]==3
	replace bracket1 = 28200 if [_n]==4
	replace bracket1 = 42600 if [_n]==5
	replace bracket1 = 60000 if [_n]==6

	xtile cat_bracket1 = selfemp, cutpoints(bracket1)  
	drop bracket1

	** THRESHOLDS
	gen thresh1=1800
	gen thresh2=7800
	gen thresh3=16800
	gen thresh4=28200
	gen thresh5=42600
	gen thresh6=60000

	* Tax Rates
	gen rate1=0.10
	gen rate2=0.15 
	gen rate3=0.20
	gen rate4=0.25
	gen rate5=0.30
	gen rate6=0.35

	gen tax1_se = .
	replace tax1_se = 0 if cat_bracket1==1
	replace tax1_se = ((selfemp - thresh1)* rate1) if cat_bracket1==2
	replace tax1_se = (((thresh2 - thresh1) * rate1) + ((selfemp - thresh2)* rate2)) if cat_bracket1==3
	replace tax1_se = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((selfemp - thresh3)* rate3)) if cat_bracket1==4
	replace tax1_se = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((selfemp - thresh4)* rate4)) if cat_bracket1==5
	replace tax1_se = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((thresh5 - thresh4) * rate4) + ((selfemp - thresh5)* rate5)) if cat_bracket1==6
	replace tax1_se = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((thresh5 - thresh4) * rate4) + ((thresh6 - thresh5) * rate5) + ((selfemp - thresh6)* rate6)) if cat_bracket1==7

	drop thresh1 thresh2 thresh3 thresh4 thresh5 thresh6 rate1 rate2 rate3 rate4 rate5 rate6 cat_bracket1

	gen net_seinc1 = selfemp - (tax1_se)

	********* SYSTEM 2: 2016 REFORM *********

	gen bracket2 = . 
	replace bracket2 = 7000 if [_n]==1
	replace bracket2 = 19300 if [_n]==2
	replace bracket2 = 37750 if [_n]==3
	replace bracket2 = 62350 if [_n]==4
	replace bracket2 = 93100 if [_n]==5
	replace bracket2 = 130000 if [_n]==6
	xtile cat_bracket2 = selfemp, cutpoints(bracket2) 
	drop bracket2

	** Thresholds
	gen thresh1=7000
	gen thresh2=19300
	gen thresh3=37750
	gen thresh4=62350
	gen thresh5=93100
	gen thresh6=130000

	* Tax Rate
	gen rate1=0.10
	gen rate2=0.15 
	gen rate3=0.20
	gen rate4=0.25
	gen rate5=0.30
	gen rate6=0.35

	gen tax2_se = .
	replace tax2_se = 0 if cat_bracket2==1
	replace tax2_se = ((selfemp - thresh1)* rate1) if cat_bracket2==2
	replace tax2_se = (((thresh2 - thresh1) * rate1) + ((selfemp - thresh2)* rate2)) if cat_bracket2==3
	replace tax2_se = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((selfemp - thresh3)* rate3)) if cat_bracket2==4
	replace tax2_se = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((selfemp - thresh4)* rate4)) if cat_bracket2==5
	replace tax2_se = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((thresh5 - thresh4) * rate4) + ((selfemp - thresh5)* rate5)) if cat_bracket2==6
	replace tax2_se = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((thresh5 - thresh4) * rate4) + ((thresh6 - thresh5) * rate5) + ((selfemp - thresh6)* rate6)) if cat_bracket2==7

	drop thresh1 thresh2 thresh3 thresh4 thresh5 thresh6 rate1 rate2 rate3 rate4 rate5 rate6 cat_bracket2

	gen net_seinc2 = selfemp - (tax2_se)


	********* SYSTEM 3: ELIMINATE POVERTY (70% MTR) *********

	gen bracket2 = . 
	replace bracket2 = 7000 if [_n]==1
	replace bracket2 = 19300 if [_n]==2
	replace bracket2 = 37750 if [_n]==3
	replace bracket2 = 62350 if [_n]==4
	replace bracket2 = 93100 if [_n]==5
	replace bracket2 = 130000 if [_n]==6
	xtile cat_bracket2 = selfemp, cutpoints(bracket2) 
	drop bracket2

	** Thresholds
	gen thresh1=7000
	gen thresh2=19300
	gen thresh3=37750
	gen thresh4=62350
	gen thresh5=93100
	gen thresh6=130000

	* Tax Rate
	gen rate1=0.10
	gen rate2=0.15 
	gen rate3=0.20
	gen rate4=0.25
	gen rate5=0.30
	gen rate6=0.7

	gen tax3_se = .
	replace tax3_se = 0 if cat_bracket2==1
	replace tax3_se = ((selfemp - thresh1)* rate1) if cat_bracket2==2
	replace tax3_se = (((thresh2 - thresh1) * rate1) + ((selfemp - thresh2)* rate2)) if cat_bracket2==3
	replace tax3_se = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((selfemp - thresh3)* rate3)) if cat_bracket2==4
	replace tax3_se = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((selfemp - thresh4)* rate4)) if cat_bracket2==5
	replace tax3_se = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((thresh5 - thresh4) * rate4) + ((selfemp - thresh5)* rate5)) if cat_bracket2==6
	replace tax3_se = (((thresh2 - thresh1) * rate1) + ((thresh3 - thresh2) * rate2) + ((thresh4 - thresh3) * rate3) + ((thresh5 - thresh4) * rate4) + ((thresh6 - thresh5) * rate5) + ((selfemp - thresh6)* rate6)) if cat_bracket2==7

	drop thresh1 thresh2 thresh3 thresh4 thresh5 thresh6 rate1 rate2 rate3 rate4 rate5 rate6 cat_bracket2
	
	gen net_seinc3 = selfemp - (tax3_se)

	label var net_seinc1 "net income from self-employment (current tax system)"
	label var net_seinc2 "net income from self-employment (2016 tax reform)"
	label var net_seinc3 "net income from self-employment (drastic tax reform)"
	ren net_seinc1 selfemp1
	ren net_seinc2 selfemp2
	ren net_seinc3 selfemp3


  
  
*******************************************************************************************************************************************
*5) MERGE IN OTHER HOUSEHOLD LEVEL VARIABLES
*******************************************************************************************************************************************
 
* merge with the riga hh characteristics data (to get the hh size variables):
	ren household_id2 hh
	merge 1:1 hh using    "$rigadata/Ethiopia13_HHCHAR.dta" 
	assert _m!=1
	keep if _m==3
	drop _m
	
	
	
*merge with consumption aggregate file & construct key vars:

	ren hh household_id2
	merge 1:1 household_id2 using  "$consdata/cons_agg_w2.dta" 
	assert _m!=1
	keep if _m==3
	drop _m
 
	gen   totincome_riga_pc=totincome2/adulteq
	ren totincome2  totincome_riga
	label var totincome_riga_pc "total income (RIGA) per adult equivalent"
	label var totincome_riga "total income (RIGA)"
	
	label var tax1 "tax on wages (current tax system)"
	label var tax2 "tax on wages (2016 tax reform)"
	label var tax3 "tax on wages (drastic tax reform)"
	ren tax1 tax1_w
	ren tax2 tax2_w
	ren tax3 tax3_w

	label var tax1_se "tax on SE income (current tax system)"
	label var tax2_se "tax on SE income (2016 tax reform)"
	label var tax3_se "tax on SE income (drastic tax reform)"
		
	 
	keep household_id2 agr_wge wage wage? crop2 livestock selfemp selfemp? transfer other  adulteq  totincome_riga* pw tax*

	*construct all income variables:
	 
	*PRE-TAX INCOME 
	egen totincome_0=rowtotal(agr_wge wage crop2 livestock selfemp transfer other)
	sum totincome_0 totincome_riga
	sum totincome_0 if totincome_0>0, det
	count if totincome_0<0
	replace totincome_0=1 if totincome_0<=0
	label var totincome_0 "total income (pre-tax)"
	gen  totincome_0_pc= totincome_0/adulteq
	label var totincome_0_pc "total income per adult equivalent (pre-tax)"
	 
 
 
	*NET-INCOME - CURRENT TAX SCHEME
	egen totincome_1=rowtotal(agr_wge wage1 crop2 livestock selfemp1 transfer other)
	count if totincome_1<0
	replace totincome_1=1 if totincome_1<=0
	label var totincome_1 "net total income (current tax scheme)"
	gen  totincome_1_pc= totincome_1/adulteq
	label var totincome_1_pc "net total income per adult equivalent (current tax scheme)"
	 
	 
	*NET-INCOME - CURRENT TAX SCHEME
	egen totincome_2=rowtotal(agr_wge wage2 crop2 livestock selfemp2 transfer other)
	count if totincome_2<0
	replace totincome_2=1 if totincome_2<=0
	label var totincome_2 "net total income (2016 tax scheme)"
	gen  totincome_2_pc= totincome_2/adulteq
	label var totincome_2_pc "net total income per adult equivalent (2016 tax scheme)"


	 
	*NET-INCOME - ELIMINATE POVERTY
	egen totincome_3=rowtotal(agr_wge wage3 crop2 livestock selfemp3 transfer other)
	count if totincome_3<0
	replace totincome_3=1 if totincome_3<=0
	label var totincome_3 "net total income (drastic tax scheme)"
	gen  totincome_3_pc= totincome_3/adulteq
	label var totincome_3_pc "net total income per adult equivalent (drastic tax scheme)"

	count


	ren household_id2 hhid

*******************************************************************************************************************************************
*6) PREPARE DATA FOR THE SOCIAL PROTECTION ANALYSIS
*******************************************************************************************************************************************	
	
preserve
	*a) gather information about public works incomes:
	use "$hhdata/sect4_hh_w2.dta" , clear
	d hh_s4q01
	keep if hh_s4q01=="X"
	d hh_s4q3?

	gen pw_inc=hh_s4q33 
	 

	ren household_id2 hhid
	collapse (sum ) pw_inc, by(hhid )
	count if pw_inc>0
	tempfile pw_inc
	save `pw_inc'
 
	*b) gather information about direct support incomes:
	use "$hhdata/sect13_hh_w2.dta" , clear
	tab hh_s13q01
	keep if  hh_s13q01==1
	tab hh_s13q02_b
	keep if hh_s13q00=="A" //PSNP related assistance //updated: 10 August 2017
  	egen ds_inc=rowtotal(hh_s13q03 hh_s13q04 hh_s13q05)
	ren household_id2 hhid
	collapse (sum ) ds_inc, by(hhid )

	*merge with PW income data:
	merge 1:1 hhid using `pw_inc'
	assert _m!=1
	drop _m
	


	replace ds_inc=0 if ds_inc==.
	assert pw_inc!=.
	assert ds_inc!=.
	egen psnp_inc=rowtotal(pw_inc ds_inc)
	count if psnp_inc>0
	tempfile sp
	save `sp'
	
restore
	 
*******************************************************************************************************************************************
*7) MERGE WITH INCOME DATA
*******************************************************************************************************************************************		
    
	merge 1:1 hhid using `sp'
	keep if _m==3
	drop _m
 
	
	assert psnp_inc!=.
	count if psnp_inc>0
 
	 
 	gen incomepc_noPSNP=(totincome_0-psnp_inc)/adulteq
 	label var incomepc_noPSNP "HH annual income per adult equivalent - PSNP income"	
    sum incomepc_noPSNP
	replace incomepc_noPSNP=1  if incomepc_noPSNP<=0
	
	label var incomepc_noPSNP "total income from PSNP per adult eq"

	*calculate the total PSNP flows:
	*collapse (sum)   psnp_inc [pweight=pw2]
 
	ren incomepc_noPSNP totincome_noPSNP_pc 
 
	total psnp_inc
 
 
 
	ren hhid household_id2 
	
	 
*******************************************************************************************************************************************
*8) TRANSFORM TO INDIVIDUAL LEVEL
*******************************************************************************************************************************************	

	merge 1:m household_id2 using  "$hhdata/sect1_hh_w2.dta", keepusing(individual_id2  saq01  pw2 rural)
	isid household_id2 individual_id2, sort
 	assert _m!=1
	keep if _m==3
	drop _m
	count if psnp_inc>0 
	 
*******************************************************************************************************************************************
*9) TIDY UP AND SAVE
*******************************************************************************************************************************************	

	keep household_id2- saq01 tax*
	order household_id2 individual_id2 saq01 rural pw2
	drop    ds_inc pw_inc  
	qui compress
	
label data "final data used for the tax & social protection paper (15 September 2016)"
save "$outputdata/et_tax_sp_data_inc.dta", replace
	
 
	
*the end

log close
 
 
